@@ -1,27 +1,18 @@
-/* This file is part of the KDE project
-  Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-            (C) 1999 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #include "browserextension.h"
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kurifilter.h>
+#include "kparts_logging.h"
+
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KUriFilter>
 
 #include <QApplication>
 #include <QClipboard>
@@ -29,8 +20,6 @@
 #include <QMap>
 #include <QRegularExpression>
 
-#include <QDebug>
-
 using namespace KParts;
 
 
@@ -285,7 +274,7 @@ void BrowserExtension::slotEnableAction(const char *name, bool enabled)
         d->m_actionStatus.setBit(it.value(), enabled);
         //qDebug() << "BrowserExtension::slotEnableAction setting bit " << it.data() << " to " << enabled;
     } else {
-        qWarning() << "BrowserExtension::slotEnableAction unknown action " << name;
+        qCWarning(KPARTSLOG) << "BrowserExtension::slotEnableAction unknown action " << name;
     }
 }
 
@@ -302,7 +291,7 @@ void BrowserExtension::slotSetActionText(const char *name, const QString &text)
     if (it != s_actionNumberMap()->constEnd()) {
         d->m_actionText[ it.value() ] = text;
     } else {
-        qWarning() << "BrowserExtension::slotSetActionText unknown action " << name;
+        qCWarning(KPARTSLOG) << "BrowserExtension::slotSetActionText unknown action " << name;
     }
 }
 
